@@ -130,7 +130,7 @@ gb_init(GB * G) {
 	G->in_shls_looperM = 0;
 	G->g_swicolM = NULL;
 	G->g_main_sig_handler = (void (*)(int))NULL;
-	G->g_safe_sig_handler =  (void (*)(int))NULL;
+	G->g_safe_sig_handler = (void (*)(int))NULL;
 	G->g_psignalM = 0;
 	G->g_running_signalsetM = 0;
 	G->g_running_signalusr1M = 0;
@@ -139,5 +139,10 @@ gb_init(GB * G) {
 	G->g_opt_previewM = 0;
 	G->g_do_cleanshM = 0;
 	G->g_gpuflagM = 0;
+	G->g_do_createM = 0;
+	G->g_do_extractM = 0;
+	G->g_sourcepath_listM = NULL;
+	G->g_no_extractM = 0;
+	G->g_do_show_linesM = 0;
 	*(G->g_gpufieldM) = '\0';
 }
