@@ -107,7 +107,7 @@ usage(FILE * fp,
 {
 	
 fprintf(fp, "%s",
-"iswverify verifies installed software\n"
+"swverify verifies installed software\n"
 );
 	
 	fprintf(fp, "%s",
@@ -139,6 +139,16 @@ fprintf(fp, "%s",
 "     --show-options-files   Show the options files that will be parsed.\n"
 "     --no-defaults-file        Do not read any defaults files.\n"
 "\n"
+"  Operational Modes\n"
+"\n"
+"    --emit-signed-file [FILE] \n"
+"    --emit-digest-file [FILE] \n"
+"    -G, --get-sig-if=OUTPUTFILE [ARCHIVEFILE]  Verifies the archive digests\n" 
+"              by comparing to the digests in the catalog and if they match\n"
+"              write the sigfile to OUTPUTFILE and the signed data to stdout.\n"
+"              For example: \n"
+"         swverify -G /dev/tty /mnt/tmp/foo-1.1.tar.gz | gpg --verify /dev/tty -\n"
+"\n"
 "  Target and Remote connection options\n"
 "\n"
 "      --remote-shell=NAME  NAME is the client \"rsh\" or \"ssh\"(default).\n"
@@ -153,15 +163,33 @@ fprintf(fp, "%s",
 "   -A,--A,--enable-ssh-agent-forwarding\n"
 "      --a,--disable-ssh-agent-forwarding\n"
 "\n"
-"  Operational Options:\n"
+"  Misc Implementation Extensions:\n"
+"\n"
+"     -W <option>[=value]   Implementation extension option\n"
+"     -W show-auth-files  Applies to emit-signed-file and emit-digest-file\n"
+"     -W sha1   applies to -Wshow-auth-files operation.\n"
+"     -W d  same as -Wshow-auth-files.\n"
+"     -W checksig [FILE]  same as --checksig.\n"
+"     -W emit-signed-file [FILE]  Writes the signed data to stdout.\n"
+"     -W C   same as -W emit-signed-file [FILE].\n"
+"     -W emit-digest-file [FILE]  Writes the digested archive data to stdout.\n"
+"     -W S   same as -W emit-digest-file.\n"
+"     -W sig-number=N Verify the Nth signature, (0 is last, 1 is first). \n"
+"     -W owner=OWNER    Specify OWNER\n"
+"     -W group=GROUP    Specify GROUP\n"
+"     -W get-sig-if=outputfile [FILE] Same as -G=OUTPUTFILE \n"
+"\n"
+"  Operational Options for installed software:\n"
 "\n"
 "      --allow-ambig  Allow multple packages to be selected by one selection spec\n"
 "      --force-locks  ignore locking, and remove existing lock.\n"
 "      --noscripts  Same as --ignore-scripts, --no-scripts\n"
 "      --ignore-scripts  Ignore (do not run) control scripts\n"
 "      --sig-level=N  N=0,1, or 2,.. number of sigs required\n"
+"      --show-auth-files  write the relavent authentication file to stderr\n"
+"                         Applies to emit-signed-file and emit-digest-file\n"
 "\n"
-"  Verification Options:\n"
+"  Verification Options for verifying installed software:\n"
 "\n"
 "      --check-permissions=true|false     Always true\n"
 "      --check-contents=true|false       Always true\n"
@@ -171,6 +199,17 @@ fprintf(fp, "%s",
 "      --check-volatile=true|false\n"
 "      --show-info     show the data that is being compared\n"
 "\n"
+"  Verification Options for verifying a directory:\n"
+"\n"
+"      --scm    Use information in the catalog to verify the catalog, and\n"
+"               set the SW_CONTROL_TAG environment variable to \"checkfile\"\n"
+"               when executing the checkdigest script.\n"
+"      --cvs   Currently, the same as --scm\n"
+"      --order-catalog   Use catalog/dfiles/files to determine the file\n"
+"                        order when verifying the directory.\n"
+"      --no-checkdigest  Do not run the checkdigest script even if present,\n"
+"                       and exit with gpg's verification status.\n"
+"\n"
 " Debugging Controls:\n"
 "\n"
 "      --debug-events             show the internal events listing to stderr\n"
@@ -178,6 +217,39 @@ fprintf(fp, "%s",
 "      --target-script-name=NAME  write the internal stdin script to NAME.\n"
 "      --debug-task-scripts       write each task shell to a file in /tmp\n"
 "\n"
+"To verify a signed tarball: \n"
+"        swverify -d @- <somepackage-0.1.tar.gz\n"
+"\n"
+"To verify a unpacked tarball: \n"
+"        swverify -d @/work/stage/swbis/sources/swbis/somepackage-0.1\n"
+"\n"
+"        Note: this requires the package contain the\n"
+"                somepackage-0.1/catalog/dfiles/checksig\n"
+"                control script.\n"
+"\n"
+"To manually verify *only* the signature of the signed current directory: \n"
+"swverify [--cvs|--order-catalog] -WC . | gpg --verify catalog/dfiles/signature -\n"
+"    # Note: Now you still must use the information in the INFO file to check\n"
+"    # the individual files.  If there is a checkdigest script in the signed\n"
+"    # stream you could run that safely now.\n"
+"\n"
+"Verify the archive digests and if valid write the signed data to stdout\n"
+"for verification by gpg via the local terminal\n"
+"(mainly for the curious and paranoid):\n"
+"   swverify -G /dev/tty foo-1.1.tar.gz | gpg --verify /dev/tty -\n"
+"   # Now copy and paste the signature block and type ctrl-D, gpg should\n"
+"   # then verify the pasted signature.\n"
+"\n"
+"Verify the digests independently (mainly for the curious and paranoid):\n"
+"   swverify -D -S --sha  foo-1.1.tar.gz | sha1sum\n"
+"   swverify -D -S  foo-1.1.tar.gz | md5sum\n"
+"   # IMPORTANT: these are not authenticated digests unless they come from a\n"
+"   # catalog verified with gpg (see the example above).\n"
+"\n"
+"\n"
+"SEE ALSO: \n"
+"libexec/swbis/arf2arf, libexec/swbis/iswverify, libexec/swbis/getopt\n"
+"\n"
 );
 
     swc_helptext_target_syntax(fp);
