@@ -79,6 +79,7 @@ construct_controlsh_script(GB * G, STROB * buf, SWI * swi)
 	swicat_construct_controlsh_taglist(swi, "*", taglist);
 
 	strob_sprintf(buf, STROB_DO_APPEND,
+		CSHID
 		"SWBCS_TAGLIST=\"%s\"\n"
 		"case \"$#\" in\n"
 		"	2)\n"
@@ -92,6 +93,7 @@ construct_controlsh_script(GB * G, STROB * buf, SWI * swi)
 		"SWBCS_SCRIPT_TAG=\"$2\"\n"
 		"SWBCS_GOT_MATCH=n\n"
 		"SWBCS_MATCH=\"\"\n"
+		CSHID
 		"for fqc in $SWBCS_TAGLIST\n"
 		"do\n"
 		"	case \"$fqc\" in\n"
@@ -102,6 +104,7 @@ construct_controlsh_script(GB * G, STROB * buf, SWI * swi)
 		"		;;\n"
 		"	esac\n"
 		"done\n"
+		CSHID
 		"case $SWBCS_GOT_MATCH in\n"
         	"	n)\n"
 		"		echo SW_SELECTION_NOT_FOUND 1>&2\n"
@@ -130,6 +133,7 @@ construct_controlsh_script(GB * G, STROB * buf, SWI * swi)
 
 	strob_sprintf(buf, STROB_DO_APPEND,
 		"\n"
+		CSHID
 		"# Now run the script\n"
 		"\n"
 		"sh \"${SW_CONTROL_DIRECTORY}/${SWBCS_SCRIPT_NAME}\"\n"
@@ -711,11 +715,11 @@ write_catalog_archive_member(SWI * swi, int ofd,
 	return retval;
 }
 
+static
 int
 send_catalog_tarfile(SWI * swi, int ofd, 
 	char * catalog_path, char * pax_read_command,
 	int alt_catalog_root, int event_fd,
-	struct tar_header * ptar_hdr,
 	int sig_block_start, int sig_block_end)
 	
 {
@@ -856,7 +860,7 @@ construct_execution_phase_script(GB * G, SWI * swi,
 	strob_sprintf(buf, STROB_DO_APPEND,
 	"# FIXME: why isn't sw_retval being set\n"
 	"sw_retval=\"${sw_retval:=0}\"\n"
-	"exit \"$sw_retval\"  # sw_retval not set here\n"
+	"exit \"$sw_retval\"\n"
 	") 1</dev/null # subshell 001\n"
 	"sw_retval=$?\n"
 	);
@@ -867,6 +871,7 @@ construct_execution_phase_script(GB * G, SWI * swi,
 	xxx = TEVENT(2, -1, SWI_TASK_CTS, "Clear to Send: status=0");
 
 	strob_sprintf(buf, STROB_DO_APPEND,
+		CSHID
 		"\n"
 		"cd \"%s\"\n"
 		"case $? in\n"
@@ -917,11 +922,11 @@ construct_execution_phase_script(GB * G, SWI * swi,
 }
 
 int
-run_analysis_script(GB * G, SWI * swi, int ofd, int event_fd)
+run_analysis_script(GB * G, SWI * swi, int ofd, int event_fd, int * p_checkinstall_status)
 {
 	int ret;
 	STROB * buf;
-	SWI_CONTROL_SCRIPT * script;
+	SWI_CONTROL_SCRIPT * checkinstall_script;
 	int stdin_file_size;
 	int this_index;
 	int script_status;
@@ -929,7 +934,7 @@ run_analysis_script(GB * G, SWI * swi, int ofd, int event_fd)
 
 	buf = strob_open(400);
 
-	ret = swpl_construct_analysis_script(G, buf, swi, &script);
+	ret = swpl_construct_analysis_script(G, buf, swi, &checkinstall_script);
 	SWLIB_ASSERT(ret == 0);
 	
 	stdin_file_size = 512;
@@ -950,23 +955,28 @@ run_analysis_script(GB * G, SWI * swi, int ofd, int event_fd)
 		 */
 		ret = etar_write_trailer_blocks(NULL, ofd, 1);
 
+		if (ret < 0) return -1;
+
 		/*
 		 * wait for the script to finish
 		 */
 		ret = swicol_rpsh_task_expect(swi->swicolM,	
 				event_fd,
 				SWICOL_TL_9 /*timelimit*/);
+		if (ret < 0) return -1;
 		/*
 		 * this shows only the events for this task script
 		 */	
 		if (swi->debug_eventsM)
 			swicol_show_events_to_fd(swi->swicolM, STDERR_FILENO, -1);
+
 	
 		checkinstall_message = swicol_rpsh_get_event_message(swi->swicolM,
        	         			SW_CONTROL_SCRIPT_BEGINS,
 					-1, 
 					&this_index);
 
+		*p_checkinstall_status = -1;  /* not set */
 		if (checkinstall_message) {
 			/*
 			 * Perform a sanity check on the message
@@ -979,7 +989,8 @@ run_analysis_script(GB * G, SWI * swi, int ofd, int event_fd)
 			 */
 	
 			script_status = swicol_rpsh_get_event_status(swi->swicolM, NULL, SW_CONTROL_SCRIPT_ENDS, this_index, &this_index);
-			script->resultM = script_status;
+			checkinstall_script->resultM = script_status;
+			*p_checkinstall_status = script_status;
 		} else {
 			/*
 			 * This is OK
@@ -1044,7 +1055,8 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	int * g_signal_flag, char * target_path, char * catalog_path, VPLOB * swspecs,
 	int altofd, int opt_preview, char * pax_read_command_key,
 	int alt_catalog_root, int event_fd, struct extendedOptions * opta,
-	int keep_old_files, uintmax_t * pstatbytes, int allow_missing_files)
+	int keep_old_files, uintmax_t * pstatbytes,
+	int allow_missing_files, SWICAT_E * up_e)
 {
 	int format;
 	int output_format;
@@ -1072,6 +1084,9 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	int optacc_a;
 	int atoi_error;
 	int files_missing_from_storage;
+	int checkinstall_status;
+	int do_check_abort;
+	int do_enforce_scripts;
 	STROB * resolved_path;
 	STROB * namebuf;
 	STROB * newnamebuf;
@@ -1113,13 +1128,15 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	SWI_PRODUCT * current_product;
 	SWI_XFILE * current_fileset;
 	char * newname_suffix;
-	int product_count = 0;  /* This is always zero until multiple products are supported */
 	char * p_location;
 	char * p_qualifier;
 	char * p_directory;
 	SWVERID * swverid;
 
+	do_check_abort = 0;
+	checkinstall_status = -1; /* unset value */
 	files_missing_from_storage = 0;
+	do_enforce_scripts = swextopt_is_option_true(SW_E_enforce_scripts, opta);
 
 	swpath_ex = swpath_shallow_create_export();
 	shell_lib_buf = strob_open(100);
@@ -1268,7 +1285,8 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			);
 
 		if (ret != 0) {
-			/* FIXME */
+			sw_e_msg(G, "error from SWBIS_TS_make_catalog_dir\n");
+			/* FIXME, set abort condition? */
 		}
 
 		ret = etar_write_trailer_blocks(NULL, ofd, 1);
@@ -1333,8 +1351,6 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		name = strob_str(namebuf);
 		data_amount = xformat_get_filesize(xformat);	
 	
-		/* fprintf(stderr, "eraseme %d %s %d\n", curpos, name, data_amount);  */
-
 		parseret = swpath_parse_path(swpath, name);
 		if (parseret < 0) {
 			SWBIS_ERROR_IMPL();
@@ -1381,7 +1397,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 				/* TS_catalog_load */
 				ret = send_catalog_tarfile(swi, vofd, 
 					catalog_path, pax_read_command,
-					alt_catalog_root, event_fd, ptar_hdr,
+					alt_catalog_root, event_fd,
 					sig_block_start, sig_block_end);
 			} else {
 				ret = 0;
@@ -1570,20 +1586,72 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		}
 	}
 
-
 	E_DEBUG("HERE");
 	if (opt_preview == 0 && retval == 0) {
 		/*
 		 * TS_analysis_002
 		 */
 		E_DEBUG("HERE");
-		ret = run_analysis_script(G, swi, vofd, event_fd);
-		if (ret) {
+		ret = run_analysis_script(G, swi, vofd, event_fd, &checkinstall_status);
+		if (ret < 0) {
+			/* internal error */
 			retval++;
 			E_DEBUG2("retval = %d", retval);
-		}
-	}
+		} else {
+			/* process the checkinstall enforcement policy 
+			   based on the script exit status */
+			
+			if (checkinstall_status == SW_SUCCESS) {
+				;	
+			} else if (checkinstall_status == SW_WARNING) {
+				;
+			} else if (checkinstall_status == SW_ERROR) {
+				if (do_enforce_scripts) {
+					do_check_abort = 1;
+				}
+			} else if (checkinstall_status == SW_DESELECT) {
+				/* even if do_enforce_scripts == 0, enforce this status
+				   as meaning deselect, only if forced override */
+				if (G->g_force == 0) {
+					do_check_abort = 1;
+				}
+			} else if (checkinstall_status == -1) {
+				/* OK, probably no checkinstall script */
+				;
+			} else {
+				/* unrecognized status */
+				sw_e_msg(G, "unrecognized exit status for checkinstall: %d\n", checkinstall_status);
+				retval++;
+			}
 
+		}
+
+		/* TS_restore_catalog_entry */
+		if (up_e && do_check_abort && retval == 0) {
+			/* restore the catalog entry */
+			ret = swpl_restore_catalog_entry(G, swi->swicolM, up_e,
+				vofd, get_opta(G->optaM, SW_E_installed_software_catalog));
+			retval++;
+		} else {
+			/* fulfill the task with nothing successfully */			
+			ret = swpl_send_nothing_and_wait(swi->swicolM, vofd, event_fd,
+					SWBIS_TS_restore_catalog_entry,
+					SWICOL_TL_4, SW_SUCCESS);
+		}
+
+		/* SWBIS_TS_continue */
+		if (do_check_abort) { 
+			retval++;
+			ret = SW_ERROR;
+		} else {
+			ret = SW_SUCCESS;
+
+		}
+		ret = swpl_send_nothing_and_wait(swi->swicolM, vofd, event_fd,
+			SWBIS_TS_continue, SWICOL_TL_4, ret);
+
+		if (ret != 0) retval++;
+	}
 
 	/*
 	 * ===================================================
@@ -1640,10 +1708,10 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			payload_size,  /* fileset size plus padding */
 			".", /* strob_str(newnamebuf), */
 			strob_str(execution_phase_script), SWBIS_TS_Load_fileset);
-		swicol_set_event_fd(swi->swicolM, -1);
-		if (ret == 0)
+		if (ret == 0) {
 			/* wait for clear-to-send */
 			ret = swicol_rpsh_wait_cts(swi->swicolM, event_fd);
+		}
 	}
 	if (ret) {
 		retval++;
@@ -2065,7 +2133,6 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 				}
 			}
 
-
 			if (md5buf && *current_type == SW_ITYPE_f) {
 				if (filemd5 == NULL) {
 					sw_e_msg(G, "Warning: md5sum attribute not found in INFO file for %s\n", current_path);
@@ -2079,6 +2146,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 					}
 				}
 			}
+
 			if (fileset_write_ret % 512) {
 				SWBIS_ERROR_IMPL();
 				return -79;
@@ -2199,8 +2267,10 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		 * Now we must read the events stack and update the script
 		 * retsults.
 		 */
-	
+
+		E_DEBUG("HERE");
 		swpl_update_execution_script_results(swi, swi->swicolM, swpl_get_script_array());
+		E_DEBUG("HERE");
 
 	} else {
 		E_DEBUG("HERE");
@@ -2235,6 +2305,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 *    var/lib/swbix/catalog/foo/foo/1.1/0/export
 	 */
 
+	E_DEBUG("HERE");
 	if (opt_preview == 0 && retval == 0) {
 		/* TS_catalog_dir_remove */
 		ret = swpl_remove_catalog_directory(swi, vofd, catalog_path, pax_read_command, alt_catalog_root, event_fd);
@@ -2250,6 +2321,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 * ===================================================
 	 */
 
+	E_DEBUG("HERE");
 	if (opt_preview == 0 && retval == 0) {
 		/* TS_load_index_file_91 */
 		swpl_update_fileset_state(swi, "*", SW_STATE_INSTALLED);
@@ -2330,6 +2402,11 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 * Done
 	 * ===================================================
 	 */
+	E_DEBUG("HERE");
+
+	if (swi->debug_eventsM) {
+		swicol_show_events_to_fd(swi->swicolM, STDERR_FILENO, 0); 
+	}
 
 	strob_close(shell_lib_buf);
 	strob_close(catalogdir);
@@ -2343,8 +2420,10 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	taru_free_header(file_hdr);
 	ahs_close(info_ahs2);
 	if (allow_missing_files) {
+		E_DEBUG2("HERE returning %d", retval);
 		return retval;
 	} else {
+		E_DEBUG2("HERE returning %d", retval || files_missing_from_storage);
 		return retval || files_missing_from_storage;
 	}
 }
@@ -2366,7 +2445,7 @@ write_target_install_script(GB * G,
 		SWI_DISTDATA * distdata,
 		char * installed_software_catalog,
 		int opt_preview,
-		char * sh_dash_s,
+		char * g_sh_dash_s,
 		int alt_catalog_root
 		)
 {
@@ -2524,9 +2603,14 @@ write_target_install_script(GB * G,
 	
 	strob_strcpy(buffer_new, "");
 
+	if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "detect") == 0) {
+		swpl_bashin_detect(buffer_new);
+	}
+
 	strob_sprintf(buffer_new, STROB_DO_APPEND,
 	"trap '/bin/rm -f ${LOCKPATH}.lock; exit 1' 1 2 15\n"
 	"echo " SWBIS_TARGET_CTL_MSG_125 ": " KILL_PID "\n"
+	CSHID
 	"%s\n" /* Session Begins */
 	"%s"
 	"opt_allow_no_lock=\"%s\"\n"
@@ -2559,8 +2643,12 @@ write_target_install_script(GB * G,
 	"isc_path=\"%s\"\n"
 	"xtarget=\"%s\"\n"
 	"wcwd=`pwd`\n"
-	"sh_dash_s=\"%s\"\n"
+	"export sh_dash_s\n"
+	"d_sh_dash_s=\"%s\"\n"
+	"case \"$5\" in PSH=*) eval \"$5\";; *) unset PSH ;; esac\n"
+	"sh_dash_s=\"${PSH:=$d_sh_dash_s}\"\n"
 	"debug_task_shell=\"%s\"\n"
+	CSHID
 	"if test -f \"$xtarget\" -o -p \"$xtarget\" -o -b \"$xtarget\" -o -c \"$xtarget\"; then\n"
 			/*
 			* error
@@ -2573,6 +2661,7 @@ write_target_install_script(GB * G,
 	"	%s\n" 				/* SW_SESSION_ENDS: status=1 */
 	"	exit $sw_retval\n"
 	"fi\n"
+	CSHID
 	"cd \"$xtarget\" 2>/dev/null\n"
 	"sw_retval=$?\n"
 	"if test \"$xtarget\" = '.'; then\n"
@@ -2593,6 +2682,7 @@ write_target_install_script(GB * G,
 	"if test \"$sw_retval\" = \"0\"; then\n"
 	"	%s\n"  /* SOC_CREATED */
 	"fi\n"
+	CSHID
 	"cd \"$xtarget\" 2>/dev/null\n"
 	"sw_retval=$?\n"
 	"if test -d \"$isc_path\"; then\n"
@@ -2608,6 +2698,7 @@ write_target_install_script(GB * G,
 
 	"swexec_status=0\n"
 	"export swexec_status\n"
+	CSHID
 	"case \"$sw_retval\" in\n"
 	"	0)\n"
 	"		# the value of catpath has no affect\n" 
@@ -2620,6 +2711,7 @@ write_target_install_script(GB * G,
 	"		exit 1\n"
 	"		;;\n"
 	"esac\n"
+	CSHID
 	"shls_bashin2 \"" SWBIS_TS_uts "\"\n"
 	"sw_retval=$?\n"
 	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_uts ";; *) shls_false_;; esac\n"
@@ -2648,7 +2740,7 @@ write_target_install_script(GB * G,
 /*----*/
 	"	case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
 
-
+	CSHID
 	"       swexec_status=$sw_retval\n"
 	"	shls_bashin2 \"" SWBIS_TS_Get_iscs_entry "\"\n"
 	"	sw_retval=$?\n"
@@ -2674,6 +2766,7 @@ write_target_install_script(GB * G,
 	"	swexec_status=$sw_retval\n"
 	"	;;\n"
 	"esac\n"
+	CSHID
 	"case \"$opt_preview\" in\n"
 	"True)\n"
 	"	shls_bashin2 \"" SWBIS_TS_preview_task "\"\n"
@@ -2690,6 +2783,7 @@ write_target_install_script(GB * G,
 	"*)\n"
 	"	;;\n"
 	"esac\n"
+	CSHID
 	"shls_bashin2 \"" SWBIS_TS_make_catalog_dir "\"\n"
 	"sw_retval=$?\n"
 	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_make_catalog_dir ";; *) shls_false_;; esac\n"
@@ -2700,6 +2794,7 @@ write_target_install_script(GB * G,
 
 	"shls_bashin2 \"" SWBIS_TS_Load_catalog "\"\n"
 	"sw_retval=$?\n"
+	CSHID
 	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Load_catalog ";; *) shls_false_;; esac\n"
 	"sw_retval=$?\n"
 	"swexec_status=$sw_retval\n"
@@ -2733,7 +2828,20 @@ write_target_install_script(GB * G,
 	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Analysis_002 ";; *) shls_false_;; esac\n"
 	"sw_retval=$?\n"
 	"swexec_status=$sw_retval\n"
+
+	"shls_bashin2 \"" SWBIS_TS_restore_catalog_entry "\"\n"
+	"sw_retval=$?\n"
+	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_restore_catalog_entry ";; *) shls_false_;; esac\n"
+	"sw_retval=$?\n"
+	"swexec_status=$sw_retval\n"
+
+	"shls_bashin2 \"" SWBIS_TS_continue "\"\n"
+	"sw_retval=$?\n"
+	"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_continue ";; *) shls_false_;; esac\n"
+	"sw_retval=$?\n"
+	"swexec_status=$sw_retval\n"
 	
+	CSHID
 	"if [ \"$opt_preview\" = \"\" ]; then\n"
 	"	%s\n"							/* SW_ANALYSIS_ENDS */
 	"fi\n"
@@ -2772,6 +2880,7 @@ write_target_install_script(GB * G,
 	"sw_retval=$?\n"
 	"swexec_status=$sw_retval\n"
 
+	CSHID
 	"%s\n" /* <<<<----- here's the code to unlock a session */
 
 	"case $swexec_status in	0) %s ;; *) shls_false_ ;; esac\n" 	/* SW_EXECUTION_ENDS */
@@ -2804,7 +2913,7 @@ write_target_install_script(GB * G,
 /*_% */	blocksize,
 /*_% */	isc_relpath,
 /*_% */	x_targetpath, 
-/*_% */	sh_dash_s,
+/*_% */	g_sh_dash_s,
 /*_% */	debug_task_shell,	/* debug_task_shell */	
 /*_% */	TEVENT(2, vlv, SW_SESSION_ENDS, "status=$sw_retval"),
 /*_% */	TEVENT(2, vlv, SW_SOC_CREATED, x_targetpath),
@@ -2825,13 +2934,13 @@ write_target_install_script(GB * G,
 	if (ret != (int)strlen(xx)) {
 		return 1;
 	}
+        if (G->g_target_script_name) {
+                swlib_tee_to_file(G->g_target_script_name, -1, xx, -1, 0);
+        }
 	free(targetpath);
 	free(source_basename);
 	free(target_dirname);
 	free(target_basename);
-        if (G->g_target_script_name) {
-                swlib_tee_to_file(G->g_target_script_name, -1, xx, -1, 0);
-        }
 
 	strob_close(lockfrag_buffer);
 	strob_close(unlockfrag_buffer);
@@ -2875,7 +2984,7 @@ swinstall_write_target_install_script(GB * G,
 		SWI_DISTDATA * distdata,
 		char * installed_software_catalog,
 		int opt_preview,
-		char * sh_dash_s,
+		char * g_sh_dash_s,
 		int alt_catalog_root
 		)
 {
@@ -2896,7 +3005,7 @@ swinstall_write_target_install_script(GB * G,
 		distdata,
 		installed_software_catalog,
 		opt_preview,
-		sh_dash_s,
+		g_sh_dash_s,
 		alt_catalog_root);
 }
 
@@ -2906,7 +3015,7 @@ swinstall_arfinstall(GB * G, SWI * swi, int ofd, int * g_signal_flag,
 	int section, int altofd, int opt_preview, char * pax_read_command_key,
 	int alt_catalog_root, int event_fd, struct extendedOptions * opta,
 	int keep_old_files, uintmax_t * pstatbytes,
-	int allow_missing_files)
+	int allow_missing_files, SWICAT_E * up_e)
 {
 	int ret;
 	int format;
@@ -2982,7 +3091,7 @@ swinstall_arfinstall(GB * G, SWI * swi, int ofd, int * g_signal_flag,
 				target_path, catalog_prefix, swspecs,
 				altofd, opt_preview, pax_read_command_key,
 				alt_catalog_root, event_fd, opta,
-				keep_old_files, pstatbytes, allow_missing_files);
+				keep_old_files, pstatbytes, allow_missing_files, up_e);
 	} else {
 		/*
 		 * all other formats
