@@ -2243,10 +2243,12 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 			   successfully, this is here as a test only. */
 			ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
 						SWBIS_TS_Do_nothing ": testing 123");
-			if (strar_num_elements(BL->attributesM) > 0) {
+
+			/* if (strar_num_elements(BL->attributesM) > 0) { */
+			if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_ATT) == 0) {
+
 				/* The -a <attribute> option was used */
 
-				/* Only support architecture */
 				char * attr;
 				attr = strar_get(BL->attributesM, 0);
 				E_DEBUG("");
