@@ -98,6 +98,7 @@ char *
 looper_locked_region(STROB * buf, int vlv)
 {
 	strob_sprintf(buf, 0,
+		CSHID
 		"				# -----------------------------\n"
 		"				# The locked region begins here\n"
 		"				# -----------------------------\n"
@@ -138,6 +139,11 @@ looper_locked_region(STROB * buf, int vlv)
 		"				sw_retval=$?\n"
 		"				swexec_status=$sw_retval\n"
 
+		"				case $swexec_status in\n"
+		"			"	xSTR(SWP_RP_STATUS_NO_GNU_TAR) ") swexec_status=0\n"
+		"				;;\n"
+		"				esac\n"
+
 		"				shls_bashin2 \"" SWBIS_TS_Catalog_dir_remove "\"\n"
 		"				sw_retval=$?\n"
 		"				case $sw_retval in 0) $sh_dash_s;; *) shls_false_;; esac\n"
@@ -243,10 +249,6 @@ ls_fileset_from_iscat(SWI * swi, int ofd, int ls_verbose)
 	return retval;
 }
 
-
-
-
-
 int
 swlist_write_source_copy_script2(GB * G,
 	int ofd, 
@@ -268,7 +270,9 @@ swlist_write_source_copy_script2(GB * G,
 	char * pax_write_command;
 	char * opt_force_lock;
 	char * opt_allow_no_lock;
+	char * xx;
 	STROB * buffer;
+	STROB * buffer_new;
 	STROB * shell_lib_buf;
 	STROB * is_archive_msg;
 	STROB * is_directory_msg;
@@ -287,6 +291,7 @@ swlist_write_source_copy_script2(GB * G,
 	basename = (char*)NULL;
 	dirname = (char*)NULL;
 	buffer = strob_open(1);
+	buffer_new = strob_open(1);
 	to_devnull = strob_open(10);
 	is_archive_msg = strob_open(1);
 	is_directory_msg = strob_open(1);
@@ -389,12 +394,19 @@ swlist_write_source_copy_script2(GB * G,
 	looper_locked_region(locked_region, vlv);
 	swpl_looper_payload_routine(looper_routine,  vlv, strob_str(locked_region));
 
+	strob_strcpy(buffer_new, "");
+	if (strcmp(get_opta(G->optaM, SW_E_swbis_shell_command), "detect") == 0) {
+		swpl_bashin_detect(buffer_new);
+	}
+
 	/* Now here is the script */
-	ret = swlib_writef(ofd, buffer, 	
+	strob_sprintf(buffer_new, STROB_DO_APPEND,
+	/* ret = swlib_writef(ofd, buffer,  */
 									/* ism_begin */
 		"trap '/bin/rm -f ${LOCKPATH}.lock; exit 1' 1 2 15\n"
 		"echo " SWBIS_TARGET_CTL_MSG_125 ": " KILL_PID "\n"
 		"export LOCKENTRY\n"
+		CSHID
 		"LOCKPATH=\"\"\n"
 		"%s\n"  			/* SEVENT: SW_SESSION_BEGINS */
 		"%s" 				/* swicol_subshell_marks */
@@ -425,7 +437,11 @@ swlist_write_source_copy_script2(GB * G,
 		"sw_targettype=unset\n"
 		"sw_retval=0\n"
 		"sb__delaytime=%d\n"
-		"sh_dash_s=\"%s\"\n"
+		"export sh_dash_s\n"
+		"d_sh_dash_s=\"%s\"\n"
+		"case \"$5\" in PSH=*) eval \"$5\";; *) unset PSH ;; esac\n"
+		"sh_dash_s=\"${PSH:=$d_sh_dash_s}\"\n"
+		"#sh_dash_s=\"/bin/bash -s\"\n"
 		"debug_task_shell=\"%s\"\n"
 		"export LOCKPATH\n"
 		"#\n"
@@ -481,6 +497,7 @@ swlist_write_source_copy_script2(GB * G,
 			notified via the "is_archive_msg" and "is_directory_msg"
 			and the $sw_targettype var has been set.  */
 
+		CSHID
 		"case \"$sw_targettype\" in\n"
 		"	\"regfile\")\n"
 				/* Just dd the file back to management host */
@@ -498,6 +515,7 @@ swlist_write_source_copy_script2(GB * G,
 		"		%s\n"
 		"		swexec_status=0\n"
 
+		CSHID
 		"shls_bashin2 \"" SWBIS_TS_uts "\"\n"
 		"sw_retval=$?\n"
 		"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_uts ";; *) shls_false_;; esac\n"
@@ -568,7 +586,7 @@ swlist_write_source_copy_script2(GB * G,
 /*_% */		sourcepath,
 /*_% */		sourcepath,
 /*_% 19 */	delaytime,
-/*_% */		G->g_sh_dash_s, 
+		swc_get_default_sh_dash_s(G),
 /*_% */		debug_task_shell,					/* debug_task_shell */	
 /*_% */		strob_str(looper_routine),
 									/* ism_test_begin */
@@ -603,13 +621,20 @@ swlist_write_source_copy_script2(GB * G,
 /*_% */		swicol_subshell_marks(subsh2, "install_target", 'R', nhops, vlv)
 		);
 
+	xx = strob_str(buffer_new);
+	ret = atomicio((ssize_t (*)(int, void *, size_t))write, ofd, xx, strlen(xx));
+	if (ret != (int)strlen(xx)) {
+		return 1;
+	}
+
 	free(basename);
 	free(dirname);
 	strob_close(tmp);
 	if (G->g_source_script_name) {
-		swlib_tee_to_file(G->g_source_script_name, -1, strob_str(buffer), -1, 0);
+		swlib_tee_to_file(G->g_source_script_name, -1, xx, -1, 0);
 	}
 	strob_close(buffer);
+	strob_close(buffer_new);
 	strob_close(is_archive_msg);
 	strob_close(is_directory_msg);
 	strob_close(set_vx);
@@ -716,7 +741,6 @@ swlist_list_distribution_archive(
 	E_DEBUG("");
 	G->g_xformat = swi->xformatM;
 
-	swi->sh_dash_sM = strdup(G->g_sh_dash_s);
 	swi->opt_alt_catalog_rootM = G->g_opt_alt_catalog_root;
 	swi->swi_pkgM->target_pathM = strdup(target_path);
 	swi->swi_pkgM->installed_software_catalogM =
@@ -1057,18 +1081,18 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	 */
 
 	swi = swicat_e_open_swi(ee);
-	swi->verboseM = G->g_verboseG;
-	swi_set_utility_id(swi, SWC_U_L);
-
 	if (swi == NULL) {
 		/* swi might be NULL due to file system permission,
 		   handle NULL gracefully */
 		do_skip_entry = 1;
 		sw_e_msg(G, "catalog read error, possible permission denied: %s/%s\n", target_path, epath);
+	} else {
+		swi->verboseM = G->g_verboseG;
+		swi_set_utility_id(swi, SWC_U_L);
+		swi->swi_pkgM->catalog_entryM = strdup(epath); /* FIXME, this must set explicitly */
+		swi->swi_pkgM->target_pathM = strdup(target_path); /* FIXME, this must set explicitly */
 	}
 
-	if (swi) swi->swi_pkgM->catalog_entryM = strdup(epath); /* FIXME, this must set explicitly */
-	if (swi) swi->swi_pkgM->target_pathM = strdup(target_path); /* FIXME, this must set explicitly */
 
 	if (G->devel_verboseM)
 		SWLIB_INFO2("NOPEN=%d", uxfio_uxfio_get_nopen());
@@ -1194,7 +1218,7 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			/* List files as installed in the file system */
 			FILE_DIGS * digs;
 			digs = taru_digs_create();
-			taru_digs_init(digs, DIGS_ENABLE_ON);
+			taru_digs_init(digs, DIGS_ENABLE_ON, 0);
 
 			ret = swpl_retrieve_files(G, swi, swicol, ee, file_list,
 				ofd, ifd, archive_fd,
@@ -1214,6 +1238,9 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			looper_abort(G, swicol, ofd);
 			goto error_out;
 		} else if (ret > 0) {
+			if (ret == SWP_RP_STATUS_NO_GNU_TAR) {
+				sw_e_msg(G, "GNU tar or pax is required for this operation but appears missing.\n");
+			}
 			rstatus = 9;
 		}
 	}
