@@ -83,6 +83,22 @@ set_ls_list_flags(void)
 	return ls_verbose;
 }
 
+static
+void
+merge_name_id(int * ls_verbose, int available_attributes)
+{
+	int x;
+	x = *ls_verbose;
+	if (available_attributes & LS_LIST_VERBOSE_WITH_SYSTEM_IDS) {
+		x |= LS_LIST_VERBOSE_WITH_SYSTEM_IDS;
+	}
+	if (available_attributes & LS_LIST_VERBOSE_WITH_SYSTEM_NAMES) {
+		x |= LS_LIST_VERBOSE_WITH_SYSTEM_NAMES;
+	}
+	*ls_verbose = x;
+}
+
+
 static
 int
 determine_ls_list_flags(int attr, struct new_cpio_header * file_hdr, int check_contents)
@@ -92,14 +108,18 @@ determine_ls_list_flags(int attr, struct new_cpio_header * file_hdr, int check_c
 	int ls_verbose;
 
 	ls_verbose = 0;
+	E_DEBUG("");
 
 	if (attr & TARU_UM_UID && attr & TARU_UM_OWNER) {
+		E_DEBUG("Has owner and uid");
 		ls_verbose |= LS_LIST_VERBOSE_WITH_SYSTEM_IDS;
 		ls_verbose |= LS_LIST_VERBOSE_WITH_SYSTEM_NAMES;
 	} else if (attr & TARU_UM_UID) {
+		E_DEBUG("Has uid only");
 		ls_verbose |= LS_LIST_VERBOSE_WITH_SYSTEM_IDS;
 		ls_verbose &= ~LS_LIST_VERBOSE_WITH_SYSTEM_NAMES;
 	} else if (attr & TARU_UM_OWNER) {
+		E_DEBUG("Has owner only");
 		ls_verbose &= ~LS_LIST_VERBOSE_WITH_SYSTEM_IDS;
 		ls_verbose |= LS_LIST_VERBOSE_WITH_SYSTEM_NAMES;
 	}
@@ -916,8 +936,6 @@ swpl_load_single_file_tar_archive (GB * G,
 	 * process on the target host.
 	 */
 
-	/* (*f_archive_data)(tmp, swi); */
-
 	stdin_file_size = \
 		swpl_get_whole_block_size((unsigned long int)strlen(data)) +  /* data plue tar block padding */
 		TARRECORDSIZE + /* ustar header */
@@ -939,7 +957,7 @@ swpl_load_single_file_tar_archive (GB * G,
 	/*
 	 * Now send the task script to the target host 'sh -s'
 	 */
-	/* swicol_set_task_idstring(swi->swicolM, id_str); */
+
 	ret = swicol_rpsh_task_send_script2(
 		swi->swicolM,
 		ofd, 			/* file descriptor */
@@ -1609,6 +1627,7 @@ swpl_write_catalog_data(SWI * swi, int ofd, int sig_block_start, int sig_block_e
 	int retval;
 	int ret;
 
+	E_DEBUG("");
 	ifd = xformat_get_ifd(xformat);
 	curpos = uxfio_lseek(ifd, 0L, SEEK_CUR);
 	if (curpos < 0) {
@@ -1616,11 +1635,13 @@ swpl_write_catalog_data(SWI * swi, int ofd, int sig_block_start, int sig_block_e
 		return -1;
 	}
 
+	E_DEBUG2("ifd=%d", ifd);
 	if (uxfio_lseek(ifd, package->catalog_start_offsetM, SEEK_SET) < 0) {
 		SWI_internal_fatal_error();
 		return -1;
 	}
 
+	E_DEBUG("");
 	if (sig_block_start > 0) {
 		iend = sig_block_start;
 	} else {
@@ -1628,11 +1649,13 @@ swpl_write_catalog_data(SWI * swi, int ofd, int sig_block_start, int sig_block_e
 	}
 	amount = iend - package->catalog_start_offsetM;
 
+	E_DEBUG("");
 	if (swlib_pump_amount(ofd, ifd, amount) != amount) {
 		SWI_internal_fatal_error();
 		return -1;
 	}
 	retval = amount;
+	E_DEBUG("");
 	if (sig_block_start > 0) {
 		/* 
 		 * skip the signatures and write the remaining.
@@ -1660,9 +1683,11 @@ swpl_write_catalog_data(SWI * swi, int ofd, int sig_block_start, int sig_block_e
 		SWI_internal_fatal_error();
 	}
 
+	E_DEBUG("");
 	/*
 	 * Now write 2 NUL trailer blocks
 	 */
+	E_DEBUG("");
 	ret = etar_write_trailer_blocks(NULL, ofd, 2);
 	if (ret < 0) {
 		fprintf(stderr, "%s: swpl_write_catalog_data(): etar_write_trailer_blocks(): ret=%d\n",
@@ -1670,6 +1695,7 @@ swpl_write_catalog_data(SWI * swi, int ofd, int sig_block_start, int sig_block_e
 		return ret;
 	}
 	retval += ret;
+	E_DEBUG("");
 	return retval;
 } 
 
@@ -3164,6 +3190,7 @@ swpl_signature_policy_accept(GB * G, SWGPG_VALIDATE * w, int verbose_level, char
 	int sig_fd;
 	int logger_fd;
 	int status_fd;
+	int not_confirmed_msg_fd;
 
 	opta = G->optaM;
 	swgpg_set_status_array(w); /* harmless if already done so do it again */
@@ -3222,6 +3249,12 @@ swpl_signature_policy_accept(GB * G, SWGPG_VALIDATE * w, int verbose_level, char
 		}
 	}
 
+	if (strcmp(swlib_utilname_get(), "swlist") == 0) {
+		not_confirmed_msg_fd = STDERR_FILENO;
+	} else {
+		not_confirmed_msg_fd = STDOUT_FILENO;
+	}
+
 	if (retval) {
 		swc_stderr_fd2_set(G, STDERR_FILENO);
 		sw_l_msg(G, SWC_VERBOSE_1, "%s at sig_level=%d for %s: %d sigs, %d good: status=1\n",
@@ -3236,7 +3269,7 @@ swpl_signature_policy_accept(GB * G, SWGPG_VALIDATE * w, int verbose_level, char
 				(sig_level == 0 && num_of_sigs > 0 && num_of_sigs == ngood) ||
 				0
 		) {
-			swc_stderr_fd2_set(G, STDOUT_FILENO);
+			swc_stderr_fd2_set(G, not_confirmed_msg_fd);
 			sw_l_msg(G, SWC_VERBOSE_2, "%s at sig_level=%d for %s: %d sigs, %d good: status=0\n",
 				swevent_code(SW_ISC_INTEGRITY_CONFIRMED), sig_level, swspec_string, num_of_sigs, ngood);
 			swc_stderr_fd2_restore(G);
@@ -3244,12 +3277,12 @@ swpl_signature_policy_accept(GB * G, SWGPG_VALIDATE * w, int verbose_level, char
 				(sig_level == 0 && num_of_sigs == 0) ||
 				0
 		) {
-			swc_stderr_fd2_set(G, STDOUT_FILENO);
+			swc_stderr_fd2_set(G, not_confirmed_msg_fd);
 			sw_l_msg(G, SWC_VERBOSE_1, "%s at sig_level=%d for %s: %d sigs, %d good: status=0\n",
 				swevent_code(SW_ISC_INTEGRITY_NOT_CONFIRMED), sig_level, swspec_string, num_of_sigs, ngood);
 			swc_stderr_fd2_restore(G);
 		} else {
-			swc_stderr_fd2_set(G, STDERR_FILENO);
+			swc_stderr_fd2_set(G, not_confirmed_msg_fd);
 			sw_l_msg(G, SWC_VERBOSE_1, "%s at sig_level=%d for %s: %d sigs, %d good: status=0\n",
 				swevent_code(SW_ISC_INTEGRITY_NOT_CONFIRMED), sig_level, swspec_string, num_of_sigs, ngood);
 			swc_stderr_fd2_restore(G);
@@ -3644,6 +3677,8 @@ swpl_ls_fileset_from_iscat(SWI * swi, int ofd, int ls_verbose, int * available_a
 			if (has_sha512) ls_verbose |= LS_LIST_VERBOSE_WITH_SHA512;
 		}
 
+		merge_name_id(&ls_verbose, *available_attributes);
+
 		swheader_restore_state(infoheader, &state1);
 
 		/*  Here is some example code for accessing and
@@ -3739,3 +3774,55 @@ swpl_bashin_detect(STROB * buf)
 	}
 	strob_sprintf(buf, STROB_DO_APPEND, "\n");
 }
+
+int
+swpl_check_package_signatures(GB * G, SWI * swi, int sig_level)
+{
+	int i;
+	int retval;
+	int ret;
+	char * s;
+	int signed_bytes_fd;
+	char * signature;
+	SWGPG_VALIDATE * swgpg;
+	STROB * gpg_status;
+	int sig_block_start;
+	int sig_block_end;
+	CPLOB * archive_files;
+	SWI_FILE_MEMBER * afile;
+
+	retval = 0;
+	swgpg = swgpg_create();
+	gpg_status = strob_open(33);
+	archive_files = swi->swi_pkgM->dfilesM->archive_filesM;
+
+	swi_examine_signature_blocks(swi->swi_pkgM->dfilesM, &sig_block_start, &sig_block_end);
+	signed_bytes_fd = swlib_open_memfd();
+	swpl_write_catalog_data(swi, signed_bytes_fd, sig_block_start, sig_block_end);
+
+	i = 0;
+	while ((afile = (SWI_FILE_MEMBER *)cplob_val(archive_files, i++))) {
+		if (
+			(s=strstr(afile->pathnameM, "/" SW_A_signature)) &&
+			(*(s + strlen("/" SW_A_signature)) == '\0')
+		) {
+			/* Got a signature
+			fprintf(stderr, "GOT a sig [%s]\n", afile->pathnameM); */
+
+			uxfio_lseek(signed_bytes_fd, 0L, SEEK_SET);
+			strob_memset(gpg_status, (int)('\0'), 500);
+			ret = swgpg_run_gpg_verify(swgpg, signed_bytes_fd, afile->dataM, G->g_verboseG, gpg_status);
+			/* FIXME for some reason swgpg_run_gpg_verify returns non-zero */
+
+			ret = swgpg_determine_signature_status(strob_str(gpg_status));
+			if (ret != 0 || G->g_verboseG >= SWC_VERBOSE_3)
+				fprintf(stderr, "%s", strob_str(gpg_status));
+			if (ret == 0)
+				retval++;
+		}
+	}
+	uxfio_close(signed_bytes_fd);
+	swgpg_delete(swgpg);
+	strob_close(gpg_status);
+	return retval;
+}
