@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 #include "swuser_config.h"
@@ -175,7 +175,7 @@ int swDefinition::write_fd (int uxfio_fd) {
    } else {
         char * keyword = get_keyword();
 	//swstructdef::return_entry_keyword (objectkeyword, get_type());
-	ret+=::swdef_write_attribute (keyword, NULL, get_level(), 0, (int)(SWPARSE_MD_TYPE_OBJ), uxfio_fd);
+	ret+=::swdef_write_attribute (keyword, NULL, 0 /*get_level()*/, 0, (int)(SWPARSE_MD_TYPE_OBJ), uxfio_fd);
    }
    p = get_next_node();
    while (p) {
