@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,15 +17,21 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 
 #ifndef swmetadata_19980601jhl_h
 #define swmetadata_19980601jhl_h
 
+extern "C" {
+#include "swuser_config.h"
+}
+
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <limits.h>
 #include <typeinfo>
 #include "swmetadata.h"
 
@@ -56,7 +62,7 @@ public:
     virtual void   set_ino(int offset) = 0;
     virtual int    get_ino(void) = 0;
     virtual void   set_p_offset (int offset) = 0;
-    virtual int    get_p_offset (void) = 0;
+    // virtual int    get_p_offset (void) = 0;
     virtual void   set_length (int len) = 0; 
     virtual void   set_length_res (int len) = 0; 
     virtual int    get_length (void) = 0; 
