@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,12 +17,21 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 #ifndef swPSF_19980516jhl_h
 #define swPSF_19960516jhl_h
 
+extern "C" {
+#include "swuser_config.h"
+}
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <limits.h>
+
 #include "swdefinition.h"
 #include "swdefinitionfile.h"
 #include "swextendeddef.h"
@@ -69,6 +78,11 @@ public:
 	set_digests1_creation(int s) {
 		swextM->set_digests1_creation(s);
 	}
+	
+	void
+	set_digests2_creation(int s) {
+		swextM->set_digests2_creation(s);
+	}
 
 	virtual int get_type(void) { return swstructdef::return_entry_index(NULL, "PSF"); }
       
