@@ -36,6 +36,7 @@ typedef struct {
 	STROB * storageM;
 } STRAR;
 
+STRAR *		strar_copy_construct	(STRAR *);
 STRAR *		strar_open	(void);
 void		strar_close	(STRAR * strar);
 void		strar_reset	(STRAR * strar); 
@@ -45,5 +46,6 @@ int 		strar_num_elements(STRAR * strar);
 char *		strar_dump_string_s(STRAR * strar, char * prefix);
 char *		strar_return_store(STRAR * strar, int len);
 void		strar_qsort(STRAR * strar, int (*)(const void*, const void*));
-
+int		strar_qsort_strcmp();
+int		strar_qsort_neg_strcmp();
 #endif
