@@ -278,8 +278,10 @@ delay_sleep_pattern2(struct timespec * io_req, int * sleepbytes, int c_amount, i
 		) {
 			doneone = 1;
 			fprintf(stderr,
-				"%s: sshd compliance delay: sleeping %d microseconds every %d bytes\n",
+				"%s: sshd efd race delay: sleeping %d microseconds every %d bytes\n",
 					swlib_utilname_get(), (int)(io_req->tv_nsec)/1000, g_burst_adjust);
+			fprintf(stderr,
+				"%s: sshd efd race delay: is not needed for openssh >=5.1\n", swlib_utilname_get());
 		}
 		nano_nanosleep(io_req->tv_nsec);
 		*sleepbytes = 0;
@@ -1360,7 +1362,6 @@ swlib_unix_dirtrunc_n(STROB * buf, int n)
 	return n - i;
 }
 
-
 int
 swlib_unix_dircat(STROB * dest, char * dirname)
 {
@@ -1527,7 +1528,8 @@ swlib_exec_filter(SHCMD ** cmd, int src_fd, STROB * output)
 		E_DEBUG("");
 		retval = shcmd_wait(cmd);
 	}
-	E_DEBUG("");
+	E_DEBUG2("retval=%d", retval);
+	E_DEBUG2("cret=%d", cret);
 	return (retval || cret);
 }
 
