@@ -6,7 +6,7 @@
    COPYING TERMS AND CONDITIONS:
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +14,7 @@
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #define FILENEEDDEBUG 1
 #undef FILENEEDDEBUG
@@ -69,10 +69,10 @@ printlogline(STROB * buf, char * sptr)
 	return 0;
 }
 
-SWUTIL *
+SWLOG *
 swutil_open(void)
 {
-	SWUTIL * swutil = malloc(sizeof (SWUTIL));
+	SWLOG * swutil = malloc(sizeof (SWLOG));
 	if (!swutil) return NULL;
 	swutil->swu_efdM = STDERR_FILENO;
 	swutil->swu_logspecM = NULL;
@@ -82,18 +82,17 @@ swutil_open(void)
 }
 
 void
-swutil_close(SWUTIL* swutil)
+swutil_close(SWLOG* swutil)
 {
 	free(swutil);
 }
 
 void
-swutil_set_stderr_fd(SWUTIL * swutil, int fd)
+swutil_set_stderr_fd(SWLOG * swutil, int fd)
 {
 	swutil->swu_efdM = fd;
 }
 
-static
 int
 doif_i_writef(int verbose_level, int write_at_level, 
 			struct sw_logspec * logspec, int fd, char * format, va_list * pap)
@@ -151,7 +150,7 @@ doif_i_writef(int verbose_level, int write_at_level,
 }
 
 XFORMAT *
-swutil_setup_xformat(SWUTIL * swutil,
+swutil_setup_xformat(SWLOG * swutil,
 		XFORMAT * xformat,
 		int source_fd0,
 		char * source_path,
@@ -245,7 +244,7 @@ swutil_writelogline(int logfd, char * sptr)
 	int ret;
 	STROB * buf = strob_open(64);
 	printlogline(buf, sptr);
-	ret = write(logfd, strob_str(buf), strob_strlen(buf));
+	ret = uxfio_unix_safe_write(logfd, strob_str(buf), strob_strlen(buf));
 	if (ret != (int)strob_strlen(buf)) {
 		SWLIB_EXCEPTION("error writing logfile");
 	}
@@ -254,7 +253,7 @@ swutil_writelogline(int logfd, char * sptr)
 }
 
 int
-swutil_doif_writef2(SWUTIL * swutil, int write_at_level, char * format, ...)
+swutil_doif_writef2(SWLOG * swutil, int write_at_level, char * format, ...)
 {
 	int ret;
 	va_list ap;
@@ -309,3 +308,55 @@ swutil_doif_writef(int verbose_level, int write_at_level,
 	return ret;
 }
 
+int
+cpp_doif_i_writef(int verbose_level,
+		int write_at_level, 
+		struct sw_logspec * logspec,
+		int fd,
+		char * cpp_FILE,
+		int cpp_LINE,
+		char * cpp_FUNCTION,
+		char * format, va_list * pap)
+{
+	int ret;
+	STROB * b;
+	b = strob_open(100);
+	strob_sprintf(b, 0, "%s:%d (%s): %s",
+			cpp_FILE,
+			cpp_LINE,
+			cpp_FUNCTION,
+			format);
+	ret = doif_i_writef(verbose_level,
+			write_at_level, 
+			logspec,
+			fd,
+			strob_str(b),
+			pap);
+	strob_close(b);
+	return ret;
+}
+
+int
+swutil_cpp_doif_writef(int verbose_level,
+		int write_at_level, 
+		struct sw_logspec * logspec,
+		int fd,
+		char * cpp_FILE,
+		int cpp_LINE,
+		char * cpp_FUNCTION,
+		char * format, ...)
+{
+	int ret;
+	va_list ap;
+	va_start(ap, format);
+	ret = cpp_doif_i_writef(verbose_level,
+			write_at_level, 
+			logspec,
+			fd,
+			cpp_FILE,
+			cpp_LINE,
+			cpp_FUNCTION,
+		 	format, &ap);
+	va_end(ap);
+	return ret;
+}
