@@ -1,11 +1,11 @@
 /* topsf.h - Open an alien format and translate to a PSF with the archive.
 
-   Copyright (C) 1999  Jim Lowe 
+   Copyright (C) 1999,2007  Jim Lowe 
 
    COPYING TERMS AND CONDITIONS:
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,7 +13,7 @@
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
          
 
 #ifndef TOPSF_19990131_H
@@ -32,11 +32,11 @@
 #include "uinfile.h"
 #include "uxfio.h"
 #include "swlib.h"
-#include "debpsf.h"
 #include "um_header.h"
 
 #define TOPSF_OPEN_NO_AUDIT	(1 << 17) 
 #define TOPSF_PSF_FORM2 	2
+#define TOPSF_PSF_FORM3 	3
 
 typedef struct {
 	char * prefix_;
@@ -60,7 +60,10 @@ typedef struct {
 	TARU * taruM;	
 	STROB * control_directoryM;	
 	time_t mtimeM;
-	DEBPSF * debpsfM; 
+	void * debpsfM;
+	void * rpmpsfM; /* does not exist */
+	char * pkgfilenameM;
+	char * checkdigestnameM;
 } TOPSF;
 
 TOPSF * topsf_open(char * package_name, int oflags);
@@ -84,4 +87,5 @@ int 	topsf_get_fd_fd(TOPSF * topsf);
 char *  topsf_make_package_prefix(TOPSF * topsf, char * cwdir);
 int     topsf_write_psf(TOPSF * topsf, int fd_out, int do_indent);
 int 	topsf_write_info(TOPSF * topsf, int fd_out, int do_indent);
+int	topsf_h_write_to_buf(XFORMAT * xformat, char * name, STROB ** buf);
 #endif
