@@ -16,6 +16,9 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
+#define FILENEEDDEBUG 1
+#undef FILENEEDDEBUG
+
 #include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,21 +39,7 @@
 #include "ls_list.h"
 #include "swevents.h"
 /* #include "swevents_array.h" */
-
 #include "debug_config.h"
-#define SWSWINEEDDEBUG 1
-#undef SWSWINEEDDEBUG 
-
-#ifdef SWSWINEEDDEBUG
-#define SWSWI_E_DEBUG(format) SWBISERROR("SWI DEBUG: ", format)
-#define SWSWI_E_DEBUG2(format, arg) SWBISERROR2("SWI DEBUG: ", format, arg)
-#define SWSWI_E_DEBUG3(format, arg, arg1) \
-			SWBISERROR3("SWI DEBUG: ", format, arg, arg1)
-#else
-#define SWSWI_E_DEBUG(arg)
-#define SWSWI_E_DEBUG2(arg, arg1)
-#define SWSWI_E_DEBUG3(arg, arg1, arg2)
-#endif 
 
 static 
 SWPATH_EX *
@@ -300,7 +289,7 @@ SWI_PACKAGE *
 swi_package_create(void)
 {
 	SWI_PACKAGE * s = (SWI_PACKAGE *)malloc(sizeof(SWI_PACKAGE));
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	swi_com_assert_pointer((void*)s, __FILE__, __LINE__);
 	swiInitListOfObjects((void**)(s->swi_coM));
 	swi_vbase_init(s, SWI_I_TYPE_PACKAGE, NULL, NULL);
@@ -338,7 +327,7 @@ SWI * swi_create(void)
 {
 	SWI * swi;
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	swi = (SWI*)malloc(sizeof(SWI));
 	swi_com_assert_pointer((void*)swi, __FILE__, __LINE__);
 	swi->xformatM = NULL;
@@ -383,7 +372,7 @@ SWI_PRODUCT *
 swi_product_create(SWHEADER * global_index_header, SWPATH_EX * current)
 {
 	SWI_PRODUCT * s = (SWI_PRODUCT *)malloc(sizeof(SWI_PRODUCT));
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	swi_com_assert_pointer((void*)s, __FILE__, __LINE__);
 
         #ifdef SWSWINEEDDEBUG
@@ -410,17 +399,17 @@ swi_product_create(SWHEADER * global_index_header, SWPATH_EX * current)
 void
 swi_product_add_fileset(SWI_PRODUCT * thisis, SWI_XFILE * v)
 {
-	SWSWI_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	swiAddObjectToList((void **)(thisis->swi_coM), (void *)v);
-	SWSWI_E_DEBUG("LEAVING");
+	E_DEBUG("LEAVING");
 }
 
 void
 swi_package_add_product(SWI_PACKAGE * thisis, SWI_PRODUCT * v)
 {
-	SWSWI_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	swiAddObjectToList((void **)(thisis->swi_coM), (void *)v);
-	SWSWI_E_DEBUG("LEAVING");
+	E_DEBUG("LEAVING");
 }
 
 int
@@ -429,7 +418,7 @@ swi_store_file(SWI * swi, char * name, SWI_XFILE * current_xfile) {
 	char * tag;
 	XFORMAT * xformat = swi->xformatM;
 	
-	SWSWI_E_DEBUG("ENTERING");
+	E_DEBUG2("ENTERING name=[%s]", name);
 	swi_com_assert_pointer((void*)current_xfile, __FILE__, __LINE__);
 	
 	fd = xformat_u_open_file(xformat, name);
@@ -443,7 +432,7 @@ swi_store_file(SWI * swi, char * name, SWI_XFILE * current_xfile) {
 		swi_xfile_add_file_member(swi, current_xfile, name, fd);
 	}
 	xformat_u_close_file(xformat, fd);
-	SWSWI_E_DEBUG("LEAVING");
+	E_DEBUG("LEAVING");
 	return 0;
 }
 
@@ -460,7 +449,7 @@ swi_expand_shared_file_control_sripts(SWI * swi, SWI_XFILE * xfile)
 	char * tag_attr;
 	char * tag_value;
 
-	SWSWI_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	swheader_reset(swheader);
 	swheader_set_current_offset_p_value(swheader, 0);
 
@@ -544,7 +533,7 @@ swi_parse_file(
 	int ofd = swlib_open_memfd();
 	int len;
 
-	SWSWI_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	ufd = xformat_u_open_file(xformat, name);
 	if (ufd < 0) {
 		swi_com_fatal_error( __FILE__, __LINE__);
@@ -576,7 +565,7 @@ swi_parse_file(
 	swi_com_assert_pointer((void*)(swi->swi_pkgM), __FILE__, __LINE__);
 	switch(swdeffile_type) {
 		case SWPARSE_SWDEF_FILETYPE_INFO:
-			SWSWI_E_DEBUG("case");
+			E_DEBUG("case");
 			swi_com_assert_pointer(
 				(void*)(swi->swi_pkgM->current_xfileM),
 					__FILE__, __LINE__);
@@ -594,7 +583,7 @@ swi_parse_file(
 				SWHEADER_GET_NEXT);
 			break;
 		case SWPARSE_SWDEF_FILETYPE_INDEX:
-			SWSWI_E_DEBUG("case");
+			E_DEBUG("case");
 			swi->swi_pkgM->baseM.global_headerM = swheader;
 			swi->swi_pkgM->baseM.header_indexM = 0;
 			swi->swi_pkgM->swdef_fdM = curfd;
@@ -619,7 +608,7 @@ swi_parse_file(
 			swi_com_fatal_error( __FILE__ ":invalid case", __LINE__);
 			break;	
 	}
-	SWSWI_E_DEBUG("LEAVING");
+	E_DEBUG("LEAVING");
 	return ret;
 }
 
@@ -636,14 +625,14 @@ swi_add_swpath_ex(SWI * swi)
 	SWPATH * swpath = swi->swpathM;
 	SWPATH_EX * swpath_ex;
 
-	SWSWI_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	swi->swi_pkgM->prev_swpath_exM = swi_get_last_swpath_ex(swi);
 
 	swpath_ex = swpath_create_export(swpath);
 	swi_com_assert_pointer((void*)swpath_ex, __FILE__, __LINE__);
 
 	cplob_add_nta(list, (char*)(swpath_ex));
-	SWSWI_E_DEBUG("LEAVING");
+	E_DEBUG("LEAVING");
 	return 0;	
 }
 
@@ -659,18 +648,18 @@ swi_handle_control_transition(SWI * swi)
 	int detect;
 	int found_edge = 0;	
 
-	SWSWI_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 	previous = swi->swi_pkgM->prev_swpath_exM;
 	current = swi_get_last_swpath_ex(swi);
 	
-	SWSWI_E_DEBUG("ENTERING");
+	E_DEBUG("ENTERING");
 
         #ifdef SWSWINEEDDEBUG
 	{
                 STROB * tmp = strob_open(100);
-		SWSWI_E_DEBUG2("Previous SWPATH_EX:\n %s\n",
+		E_DEBUG2("Previous SWPATH_EX:\n %s\n",
 			swpath_ex_print(previous, tmp, "previous"));
-		SWSWI_E_DEBUG2("Current  SWPATH_EX:\n %s\n",
+		E_DEBUG2("Current  SWPATH_EX:\n %s\n",
 			swpath_ex_print(current, tmp, "current"));
                 strob_close(tmp);
 	}
@@ -701,12 +690,12 @@ swi_handle_control_transition(SWI * swi)
 		/*
 		 * New dfiles.
 		 */
-		SWSWI_E_DEBUG("New dfiles");
+		E_DEBUG("New dfiles");
 		package->dfilesM = swi_xfile_create(SWI_XFILE_TYPE_DFILES,
 					SWI_INDEX_HEADER(swi), current);
 		package->current_xfileM = package->dfilesM;
 		package->dfilesM->package_pathM = strdup(current->pkgpathname);
-		SWSWI_E_DEBUG2("Setting Current XFILE (dfiles) [%p]",
+		E_DEBUG2("Setting Current XFILE (dfiles) [%p]",
 					(void*)(package->current_xfileM));
 		found_edge = 1;
 	}
@@ -717,7 +706,7 @@ swi_handle_control_transition(SWI * swi)
 		/*
 		 * New product.
 		 */
-		SWSWI_E_DEBUG("New Product");
+		E_DEBUG("New Product");
 		package->current_productM = swi_product_create(SWI_INDEX_HEADER(swi), current);
 		swi_package_add_product(package, package->current_productM);
 		package->current_xfileM = NULL;
@@ -743,9 +732,9 @@ swi_handle_control_transition(SWI * swi)
 		} else {
 			;
 		}
-		SWSWI_E_DEBUG2("Setting Current Product [%p]",
+		E_DEBUG2("Setting Current Product [%p]",
 				(void*)(package->current_productM));
-		SWSWI_E_DEBUG2("Setting Current XFILE (NULL) [%p]",
+		E_DEBUG2("Setting Current XFILE (NULL) [%p]",
 					(void*)(package->current_xfileM));
 		found_edge = 1;
 	}
@@ -755,15 +744,15 @@ swi_handle_control_transition(SWI * swi)
 		/*
 		 * New fileset.
 		 */
-		SWSWI_E_DEBUG("New Fileset");
+		E_DEBUG("New Fileset");
 		fileset = swi_xfile_create(SWI_XFILE_TYPE_FILESET, SWI_INDEX_HEADER(swi), current);
 		swi_product_add_fileset(package->current_productM, fileset);
 		package->current_xfileM = fileset;
 		package->current_xfileM->package_pathM = 
 						strdup(current->pkgpathname);
-		SWSWI_E_DEBUG2("        Current Product [%p]",
+		E_DEBUG2("        Current Product [%p]",
 				(void*)(package->current_productM));
-		SWSWI_E_DEBUG2("Setting Current XFILE (fileset) [%p]",
+		E_DEBUG2("Setting Current XFILE (fileset) [%p]",
 					(void*)(package->current_xfileM));
 		found_edge = 1;
 	}
@@ -773,7 +762,7 @@ swi_handle_control_transition(SWI * swi)
 		/*
 		 * New pfiles.
 		 */
-		SWSWI_E_DEBUG("New pfiles");
+		E_DEBUG("New pfiles");
 		pfiles = swi_xfile_create(SWI_XFILE_TYPE_PFILES, SWI_INDEX_HEADER(swi), current);
 		if (package->current_productM == NULL) {
 			/*
@@ -787,14 +776,14 @@ swi_handle_control_transition(SWI * swi)
 		pfiles->package_pathM = strdup(current->pkgpathname);
 		package->current_productM->pfilesM = pfiles;
 		package->current_xfileM = pfiles;
-		SWSWI_E_DEBUG2("   Current Product [%p]",
+		E_DEBUG2("   Current Product [%p]",
 				(void*)(package->current_productM));
-		SWSWI_E_DEBUG2("Setting Current XFILE (pfiles) [%p]",
+		E_DEBUG2("Setting Current XFILE (pfiles) [%p]",
 					(void*)(package->current_xfileM));
 		found_edge = 1;
 	}
 
-	SWSWI_E_DEBUG2("LEAVING return value = [%d]", found_edge);
+	E_DEBUG2("LEAVING return value = [%d]", found_edge);
 	return found_edge;
 }
 
@@ -836,7 +825,7 @@ swi_decode_catalog(SWI * swi)
 
 	while(name) {
 		header_bytes = ret;
-		SWSWI_E_DEBUG("");
+		E_DEBUG("");
 		if (xformat_is_end_of_archive(xformat)){
 			/* 
 			 * error 
@@ -850,10 +839,11 @@ swi_decode_catalog(SWI * swi)
 		 * characters in the pathname.
 		 */
 		swi_com_check_clean_relative_path(name);
+		E_DEBUG2("name=[%s]", name);
 
 		swpath_ret = swpath_parse_path(swpath, name);
 		if (swpath_ret < 0) {
-			SWSWI_E_DEBUG("");
+			E_DEBUG("");
 			fprintf(stderr, "%s: error parsing pathname [%s]\n", swlib_utilname_get(), name);
 			retval = -2;
 			break;
@@ -865,7 +855,7 @@ swi_decode_catalog(SWI * swi)
 			 * Either -1 leading dir, or 1 catalog.
 			 */
 			if (is_catalog == 1 && catalog_start_offset < 0) {
-				SWSWI_E_DEBUG("");
+				E_DEBUG("");
 				catalog_start_offset = offset;
 				swi->swi_pkgM->catalog_start_offsetM = offset;
 				/*
@@ -883,7 +873,7 @@ swi_decode_catalog(SWI * swi)
 				 * specified when being unpacked (by tar)
 				 * and deleted.
 				 */
-				SWSWI_E_DEBUG("");
+				E_DEBUG("");
 				strob_strcpy(tmp, swpath_get_prepath(swpath));
 				swlib_unix_dircat(tmp, SW_CATALOG);
 				swi->exported_catalog_prefixM = strdup(strob_str(tmp));
@@ -897,7 +887,7 @@ swi_decode_catalog(SWI * swi)
 				/*
 				 * error
 				 */	
-				SWSWI_E_DEBUG("");
+				E_DEBUG("");
 				swi_com_assert_pointer((void*)NULL, 
 						__FILE__, __LINE__);
 			}
@@ -908,7 +898,7 @@ swi_decode_catalog(SWI * swi)
 				/*
 				 * parse the IEEE 1387.2 software definition file
 				 */
-				SWSWI_E_DEBUG("");
+				E_DEBUG("");
 				swdef_ret = swi_parse_file(swi, name, 
 							swdeffile_type);
 				if (swdef_ret) {
@@ -922,14 +912,14 @@ swi_decode_catalog(SWI * swi)
 				/*
 				 * Store the file data.
 				 */
-				SWSWI_E_DEBUG("");
+				E_DEBUG("");
 				swi_store_file(swi, name,
 					swi->swi_pkgM->current_xfileM);
 			} else {
 				/*
 				 * No data
 				 */
-				SWSWI_E_DEBUG("");
+				E_DEBUG("");
 				copyret = 0;	
 				;
 			}
@@ -937,12 +927,12 @@ swi_decode_catalog(SWI * swi)
 				/*
 				 * error
 				 */
-				SWSWI_E_DEBUG("");
+				E_DEBUG("");
 				SWI_internal_error();
 				retval = -4;
 				break;
 			}
-			SWSWI_E_DEBUG("");
+			E_DEBUG("");
 			catalog_end_offset = uxfio_lseek(ifd, (off_t)0, SEEK_CUR);	
 			swi->swi_pkgM->catalog_end_offsetM = catalog_end_offset;
 		} else {
@@ -951,16 +941,16 @@ swi_decode_catalog(SWI * swi)
 			 * Finished, read past catalog section
 			 * This is the first file of the storage section.
 			 */
-			SWSWI_E_DEBUG("");
+			E_DEBUG("");
 			swi->does_have_payloadM = 1;
 			break;
 		}
 
-		SWSWI_E_DEBUG("");
+		E_DEBUG("");
 		oldoffset = offset;
 		name = xformat_get_next_dirent(xformat, &st);
 		offset = uxfio_lseek(ifd, (off_t)0, SEEK_CUR);
-		SWSWI_E_DEBUG("");
+		E_DEBUG("");
 	}
 
 	if (retval < 0) {
@@ -989,7 +979,7 @@ swi_decode_catalog(SWI * swi)
 	ret = swi_expand_shared_file_control_sripts(swi, swi->swi_pkgM->swi_coM[0]->pfilesM);
 	swi_com_assert_value(ret == 0, __FILE__, __LINE__);
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 
 	swi_recurse_swi_tree(swi, (char *)(NULL), swi_vbase_set_verbose_level, (void*)(&(swi->verboseM)));
 	swi_recurse_swi_tree(swi, (char *)(NULL), swi_vbase_update, NULL);
@@ -1166,7 +1156,7 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 	int format;
 	int flags;
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	SWLIB_ASSERT(source_fd0 >= 0);
 	swlib_doif_writef(verboseG, SWC_VERBOSE_IDB,
 					g_logspec, swutil->swu_efdM, 
@@ -1181,7 +1171,7 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 	   forced up a level so the top level utility can
 	   control the policy */
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	if (uinfile_open_flags < 0) {
 		flags = UINFILE_DETECT_FORCEUXFIOFD |
 			UINFILE_DETECT_UNCPIO |
@@ -1192,7 +1182,7 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 	
 	/* Now, open the package */
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	xformat = swutil_setup_xformat(swutil,
 			xformat,
 			source_fd0,
@@ -1204,10 +1194,10 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 			flags);
 
 	if (xformat == (XFORMAT*)NULL) {
-		SWSWI_E_DEBUG("error");
+		E_DEBUG("error");
 		return -1;
 	}
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	
 	/* The package is now opened and partially decoded */
 
@@ -1376,7 +1366,7 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 	SWHEADER * global_index;
 	SWHEADER_STATE state;
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	flist = swi_fl_create();
 	tmp = strob_open(12);
 	relocated_path = strob_open(12);
@@ -1386,7 +1376,7 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 		return NULL;
 	}
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 
 	/* Get the product */
 	product = swi_package_get_product(swi->swi_pkgM, product_num);
@@ -1395,7 +1385,7 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 		return NULL;
 	}
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 
 	/* Get the INFO file for the fileset */
 	infoheader = swi_get_fileset_info_header(swi, product_num, fileset_num);
@@ -1409,13 +1399,13 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 	directory = swheader_get_single_attribute_value(global_index, SW_A_directory);
 	directory = swlib_attribute_check_default(SW_A_product, SW_A_directory, directory);
 	
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	swheader_store_state(infoheader, &state);
 	swheader_reset(infoheader);
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	while ((object_line = swheader_get_next_object(infoheader, (int)(UCHAR_MAX), (int)UCHAR_MAX)) != NULL) {
-		SWSWI_E_DEBUG("");
+		E_DEBUG("");
 		if (swheaderline_get_type(object_line) != SWPARSE_MD_TYPE_OBJ) {
 			SWLIB_ERROR("");
 			return NULL;
@@ -1429,16 +1419,16 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 			SWLIB_ERROR("unexpected null path");
 		}
 		/* need to check if its a volatile file */
-		SWSWI_E_DEBUG2("path=[%s]", path);
+		E_DEBUG2("path=[%s]", path);
 
 
 		/* apply relocation */
 		if (strcmp(location, "/") != 0) {
-			SWSWI_E_DEBUG2("path=[%s]", path);
+			E_DEBUG2("path=[%s]", path);
 			swlib_apply_location(relocated_path, path, location, directory);
-			SWSWI_E_DEBUG2("path=[%s]", path);
+			E_DEBUG2("path=[%s]", path);
 			path =  strob_str(relocated_path);
-			SWSWI_E_DEBUG2("path=[%s]", path);
+			E_DEBUG2("path=[%s]", path);
 		}
 		/* SWLIB_ERROR2("path=[%s]", path); */
 
@@ -1448,15 +1438,15 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 		if (*path == '.' && *(path+1) == '/') {
 			prefix = "";
 		} else {
-			SWSWI_E_DEBUG2("path=[%s]", path);
+			E_DEBUG2("path=[%s]", path);
 			path = swlib_return_relative_path(path);
-			SWSWI_E_DEBUG2("path=[%s]", path);
+			E_DEBUG2("path=[%s]", path);
 			prefix = "./";
 		}
-		SWSWI_E_DEBUG2("path=[%s]", path);
+		E_DEBUG2("path=[%s]", path);
 		store = swi_fl_add_store(flist, strlen(path)+strlen(prefix));
 		swi_fl_set_path(flist, store, prefix, path);
-		SWSWI_E_DEBUG2("path=[%s]", path);
+		E_DEBUG2("path=[%s]", path);
 		
 		/* Set the file type */
 		filetype = swheader_get_single_attribute_value(infoheader, SW_A_type);
@@ -1472,7 +1462,7 @@ swi_make_fileset_file_list(SWI * swi, int product_num, int fileset_num, char * l
 		ret = swlib_is_option_true(is_volatile);
 		swi_fl_set_is_volatile(flist, store, -1, ret);
 	}
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 out:
 	swheader_restore_state(infoheader, &state);
 	strob_close(tmp);
@@ -1506,7 +1496,7 @@ swi_make_file_list(SWI * swi, SWUTS * swuts, char * location, int disallow_incom
 	SWHEADER * global_index;
 	SWHEADER_STATE state;
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	flist = swi_fl_create();
 	tmp = strob_open(12);
 	relocated_path = strob_open(12);
@@ -1516,7 +1506,7 @@ swi_make_file_list(SWI * swi, SWUTS * swuts, char * location, int disallow_incom
 		return NULL;
 	}
 
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 	/*  swi_find_compatible_product() marks product->is_compatibleM = SW_TRUE */
 	n_compat = swi_find_compatible_product(swi, swuts, &n_products);
 
@@ -1545,7 +1535,7 @@ swi_make_file_list(SWI * swi, SWUTS * swuts, char * location, int disallow_incom
 		SWLIB_WARN("more than one compatible product found");
 		;
 	}
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 
 	check_found = 0;
 	product_number = 0;
@@ -1561,7 +1551,7 @@ swi_make_file_list(SWI * swi, SWUTS * swuts, char * location, int disallow_incom
 		SWLIB_ERROR("");
 		return NULL;
 	}
-	SWSWI_E_DEBUG("");
+	E_DEBUG("");
 
 	/* Ok, if we've made it this far the product given by
 	   product_number is the correct product for this installation
@@ -1594,15 +1584,15 @@ swi_fl_add_store(SWI_FILELIST * fl, int len) {
 
 void
 swi_fl_set_path(SWI_FILELIST * fl, char * s,  char * prefix, char * path) {
-	SWSWI_E_DEBUG2("path=[%s]", path);
-	SWSWI_E_DEBUG2("prefix=[%s]", prefix);
+	E_DEBUG2("path=[%s]", path);
+	E_DEBUG2("prefix=[%s]", prefix);
 	if (prefix == NULL) prefix = "";
 	if (strlen(prefix) > 0) {
 		strncpy(s + (SWI_FL_HEADER_LEN), prefix, strlen(prefix));
-		SWSWI_E_DEBUG2("s=[%s]", s);
+		E_DEBUG2("s=[%s]", s);
 	}
 	strncpy(s + (SWI_FL_HEADER_LEN + strlen(prefix)), path, strlen(path));
-	SWSWI_E_DEBUG2("s=[%s]", s);
+	E_DEBUG2("s=[%s]", s);
 		/* NUL is added by strar_return_store() it must
 		   be the only terminating NUL for the record otherwise
 		   the STRAR object is corrupted. */
