@@ -10,7 +10,7 @@
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 
 #include "swuser_config.h"
@@ -56,6 +56,7 @@ taru_read_in_old_ascii2 (TARU * taru, struct new_cpio_header * file_hdr, int in_
   unsigned long rdev;
   int bytesread = 0;
   int ret;
+  unsigned long xxsize;
 
   if ( buf ) {
       memcpy(ascii_header, buf, 70);
@@ -69,7 +70,8 @@ taru_read_in_old_ascii2 (TARU * taru, struct new_cpio_header * file_hdr, int in_
 	  &dev, &file_hdr->c_ino,
 	  &file_hdr->c_mode, &file_hdr->c_uid, &file_hdr->c_gid,
 	  &file_hdr->c_nlink, &rdev, &file_hdr->c_mtime,
-	  &file_hdr->c_namesize, &file_hdr->c_filesize);
+	  &file_hdr->c_namesize, &xxsize);
+  file_hdr->c_filesize = xxsize;
   file_hdr->c_dev_maj = major(dev);
   file_hdr->c_dev_min = minor(dev);
   file_hdr->c_rdev_maj = major(rdev);
