@@ -261,7 +261,7 @@ tarui_write_archive_member_(TARU * taru,
 		}
 	} else {
 		if (file_hdr0->digsM)
-			taru_digs_init(file_hdr0->digsM, DIGS_ENABLE_CLEAR);
+			taru_digs_init(file_hdr0->digsM, DIGS_ENABLE_CLEAR, 0);
 	}
 	ahsStaticDeleteFilehdr(file_hdr);
 	return ret + ret1;
