@@ -7,7 +7,7 @@
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -17,12 +17,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 #ifndef UINFILE_H_19990304
 #define UINFILE_H_19990304
 
+#include "swuser_config.h"
 #include <signal.h>
 #include "swpath.h"
 #include "uxfio.h"
@@ -56,6 +57,9 @@
 #define UINFILE_MAGIC_bz2 	"\x42\x5a\x68"
 #define UINFILE_MAGIC_ar 	"!<arch>\n"
 #define UINFILE_MAGIC_deb 	UINFILE_MAGIC_ar "debian-binary"
+#define UINFILE_MAGIC_binary_tarball	"./"
+#define UINFILE_MAGIC_slack	"install"
+#define UINFILE_MAGIC_slack_desc	UINFILE_MAGIC_slack "slack-desc"
 
 #define UINFILE_SWBIS_PATH0	"catalog/swbis-0.2/"
 #define UINFILE_SW_MAGIC	"catalog/INDEX"
@@ -83,6 +87,9 @@
 #define UINFILE_UXFIO_BUFTYPE_FILE		(1 << 15) 
 #define UINFILE_DETECT_UNRPM			(1 << 16) /* Convert an RPM to IEEE format */
 #define UINFILE_DETECT_UNCPIO			(1 << 17) /* Convert to tar format */
+#define UINFILE_DETECT_DEB_DATA			(1 << 18) /* return fd to data.tar.gz */
+#define UINFILE_DETECT_DEB_CONTROL		(1 << 19) /* return fd to control.tar.gz */
+#define UINFILE_DETECT_DEB_CONTEXT		(1 << 20) /* return fd to control.tar.gz */
 
 /* this order is the same as the arf_format enumeration in GNU cpio */
 #define UNKNOWN_FILEFORMAT		0	/* arf_unknown		*/
@@ -97,6 +104,8 @@
 #define RPMRHS_FILEFORMAT       	9       /* RedHat Format */
 #define UINFILE_FILESYSTEM		10	/* the file is a directory in the file system. */
 #define DEB_FILEFORMAT			11	/* debian package format */
+#define SLACK_FILEFORMAT		12	/* slackware package format */
+#define PLAIN_TARBALL_SRC_FILEFORMAT	13	/* common free software source tarball */
 
 #define UINFILE_FILELAYOUT_NA			100	/* not applicable */
 #define UINFILE_FILELAYOUT_IEEE			101	/* IEEE 1387.2 layout */
@@ -120,6 +129,11 @@ typedef struct {
    sigset_t blockmask_;
    sigset_t defaultmask_;
    int current_pos_;
+   int deb_file_fd_; /* FIXME redundant with underlying_fdM, fd of ar() archive file */
+   int deb_peeked_bytesM[12];
+   int n_deb_peeked_bytesM;
+   unsigned char * slackheaderM; /* leading ./ archive member */
+   char * pathname_prefixM;
 } UINFORMAT;
 
 int     uinfile_get_layout_type(UINFORMAT * uinformat);
